var configurations = require('../configurations/configurations').configurations;

var config = {
	cors: configurations.cors,
	allowOrigin: function(origin){
		origin = origin.toLowerCase();
		return (this.cors.allowOrigins == '*' || this.cors.allowOrigins.indexOf(origin) >= 0);
	},
	allowMethod: function(method){
		method = method.toUpperCase();
		return (method == 'OPTIONS' || this.cors.allowMethods.indexOf(method) >= 0);
	}
};

var process = function(request, response){
	var patharray = request.url.split('.');
	var ext = patharray[patharray.length - 1];
	var matched = ext.match(configurations.cors.filenameextension);
	if(!matched){
		return {
			continue: true
		};
	}
	
	var currentOrigin = request.headers['origin'] || '';
	var currentMethod =  request.method.toUpperCase();
	
	if(currentOrigin == ''){
		//若origin为空，则说明是从URL直接请求，不是被页面引用而请求，所以不需要返回cors-headers
		return {
			continue: currentMethod != 'OPTIONS'
		};
	}
	
    response.setHeader('Access-Control-Allow-Origin', configurations.cors.allowOrigins);
    response.setHeader('Access-Control-Allow-Headers', request.headers['Access-Control-Request-Headers'] ? request.headers['Access-Control-Request-Headers'] : configurations.cors.allowHeaders);
    response.setHeader('Access-Control-Allow-Methods', configurations.cors.allowMethods);
    response.setHeader('Access-Control-Max-Age', configurations.cors.cacheMaxAge);
    
    if(currentMethod == 'OPTIONS'){
    	//若method为OPTIONS,则视为浏览器发起的pre-flight request,此时不需要返回任何内容，只需要cors-headers即可
    	return{
			continue: false
    	};
    }
    
    return{
		continue: config.allowMethod(currentMethod) && config.allowOrigin(currentOrigin)
	};
};

exports.process = process;
