var configurations = require('../configurations/configurations').configurations;
var url = require('url');
var fs = require('fs');
var path = require('path');
var zlib = require('zlib');

var assets = function(request, response, pathname){
	
	var realPath = path.join(configurations.assetspath, pathname.replace(/\//g, '\\'));
	console.log(realPath);
	fs.exists(realPath, function(exists) {
		if (!exists) {
            response.writeHead(404, {'Content-Type': 'text/plain'});
            response.write('URL NOT FOUND: ' + pathname);
            response.end();
		} else {
			//Content-Type
			var ext = path.extname(realPath); 
			ext = ext ? ext.slice(1) : 'unknown';
			var contentType = configurations.mime[ext] || 'text/plain';
            response.setHeader('Content-Type', contentType + ';charset=utf8');

            fs.stat(realPath, function (err, stat) {
            	//Last-Modified
                var lastModified = stat.mtime.toUTCString();
                response.setHeader('Last-Modified', lastModified);
				//Expires && Cache-Control
                var expires = new Date();
                expires.setTime(expires.getTime() + configurations.browsercacheseconds * 1000);
                response.setHeader('Expires', expires.toUTCString());
                response.setHeader('Cache-Control', 'max-age=' + configurations.browsercacheseconds);

                var ifModifiedSinceTime = request.headers['If-Modified-Since'.toLowerCase()] ? new Date(request.headers['If-Modified-Since'.toLowerCase()]) : new Date(1900, 0, 1);
                var lastModifiedTime = new Date(lastModified);
                
                if (ifModifiedSinceTime >= lastModifiedTime) {
                    response.writeHead(304, 'Not Modified');
                    response.end();
                } else {
                    var raw = fs.createReadStream(realPath);
                    var acceptEncoding = request.headers['accept-encoding'] || '';
                    var matched = ext.match(configurations.compress.filenameextension);

                    if (matched && acceptEncoding.match(/\bgzip\b/)) {
                        response.writeHead(200, 'Ok', {'Content-Encoding': 'gzip'});
                        raw.pipe(zlib.createGzip()).pipe(response);
                    } else if (matched && acceptEncoding.match(/\bdeflate\b/)) {
                        response.writeHead(200, 'Ok', {'Content-Encoding': 'deflate'});
                        raw.pipe(zlib.createDeflate()).pipe(response);
                    } else {
                        response.writeHead(200, 'Ok');
                        raw.pipe(response);
                    }
                }
            });
		}
	});
};


exports.assets = assets;